# Foran

In front or behind (Danish: foran eller bagved)? Answering the question if a local repository status is in front of or behind its remote.

[License: MIT](https://git.sr.ht/~sthagen/foran/tree/default/item/LICENSE)

Third party dependencies are documented in the folder [third-party](docs/third-party/README.md).

[![version](https://img.shields.io/pypi/v/foran.svg?style=flat)](https://pypi.python.org/pypi/foran/)
[![downloads](https://pepy.tech/badge/foran/month)](https://pepy.tech/project/foran)
[![wheel](https://img.shields.io/pypi/wheel/foran.svg?style=flat)](https://pypi.python.org/pypi/foran/)
[![supported-versions](https://img.shields.io/pypi/pyversions/foran.svg?style=flat)](https://pypi.python.org/pypi/foran/)
[![supported-implementations](https://img.shields.io/pypi/implementation/foran.svg?style=flat)](https://pypi.python.org/pypi/foran/)

The English "in front" may translate to the Danish "foran".

... and the default report stem `foran-eller-bagved` alludes to the English "In front or behind?" question which corresponds to the Danish "Foran eller bagved?"

## Documentation

User and developer [documentation of foran](https://codes.dilettant.life/docs/foran).

## Bug Tracker

Any feature requests or bug reports shall go to the [todos of foran](https://todo.sr.ht/~sthagen/foran).

## Primary Source repository

The main source of `foran` is on a mountain in central Switzerland.
We use distributed version control (git).
There is no central hub.
Every clone can become a new source for the benefit of all.
The preferred public clones of `foran` are:

* [on codeberg](https://codeberg.org/sthagen/foran) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/foran) - a collection of tools useful for software development.

## Contributions

Please do not submit "pull requests" (I found no way to disable that "feature" on GitHub).
If you like to share small changes under the repositories license please kindly do so by sending a patchset.
You can either send such a patchset per email using [git send-email](https://git-send-email.io) or 
if you are a sourcehut user by selecting "Prepare a patchset" on the summary page of your fork at [sourcehut](https://git.sr.ht/).

## Status

Experimental.

**Note**: The default branch is `default`.
